@@ -1,11 +1,11 @@
-# $Id$
+# $Id: Astro.pm 3686 2007-05-27 15:26:57Z lestrrat $
 #
 # Copyright (c) 2004-2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
 
 package DateTime::Util::Astro;
 use strict;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 1;
 
@@ -15,6 +15,10 @@ __END__
 
 DateTime::Util::Astro - Utilities for Astronomical Calculations
 
+=head1 DESCRIPTION
+
+See DateTime::Util::Astro::Moon and DateTime::Util::Astro::Sun
+
 =head1 AUTHOR
 
 Copyright (c) 2004-2007 Daisuke Maki E<lt>daisuke@endeworks.jpE<gt>
